# Table of Contents

- [sending-out-surveys](<./sending-out-surveys.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Sending Out the Surveys](<./Sending-Out-the-Surveys.md>)
  - [Introduction](<./Sending-Out-the-Surveys/Introduction.md>)
  - [Previewing the Survey](<./Sending-Out-the-Surveys/Previewing-the-Survey.md>)
  - [Defining Survey Recipients](<./Sending-Out-the-Surveys/Defining-Survey-Recipients.md>)
  - [Setting Due Dates for Survey Completion](<./Sending-Out-the-Surveys/Setting-Due-Dates-for-Survey-Completion.md>)
  - [Creating Survey Emails](<./Sending-Out-the-Surveys/Creating-Survey-Emails.md>)
  - [Testing the Survey](<./Sending-Out-the-Surveys/Testing-the-Survey.md>)
